## Introduction

A wrapper based on [lightning-template](https://github.com/shenmishajing/lightning_template) for mmlab repos to use in [project-template](https://github.com/shenmishajing/project_template)

## Feature

All features from [lightning-template](https://github.com/shenmishajing/lightning_template)

## Installation

See [installation docs](docs/installation/installation.md) for details.

## Usage

### CLI

See [tool docs](docs/tools/cli.md) for details.

### Models and Datasets

See [model doc](docs/core/model.md) and [dataset doc](docs/core/dataset.md) for details.
